==========================
atelier README
==========================

A collection of tools for software artists

Description
-----------

`atelier` is a collection of tools for managing and maintaining
Python software projects.

It contains

- some general Python utilities
  (`atelier.utils <http://atelier.lino-framework.org/api/atelier.utils.html>`_)
- a library for generating reStructuredText from Python
  (`atelier.rstgen <http://atelier.lino-framework.org/api/atelier.rstgen.html>`_)
- some Sphinx extensions
  (`atelier.sphinxconf <http://atelier.lino-framework.org/api/atelier.sphinxconf.html>`_)
- a library of fabric commands
  (`atelier.fablib <http://atelier.lino-framework.org/api/atelier.fablib.html>`_)
- a minimalistic project management
  (`atelier.projects <http://atelier.lino-framework.org/api/atelier.projects.html>`_)



Read more on http://atelier.lino-framework.org
